#' Omnidirectional R Code Snippets
#'
#' The package provides a variety of functions which I regularly use during my 
#' everyday work.
#'
#' @name Orcs-package
#' @aliases orcspackage
#' @docType package
#' @title Omnidirectional R Code Snippets.
#' @author Florian Detsch, Tim Appelhans, Baptiste Auguie, 
#' OpenStreetMap contributors \cr
#' \cr
#' \emph{Maintainer:} Florian Detsch \email{fdetsch@web.de}
#'
#' @import methods grid knitr lattice latticeExtra stats
#' @importFrom bookdown render_book
#' @importFrom grDevices rgb
#' @importFrom plotrix thigmophobe
#' @importFrom Rcpp sourceCpp
#' @importFrom remotes install_github
#' @importFrom sf st_as_sf
#' @importFrom sp proj4string
#' @rawNamespace useDynLib(Orcs, .registration = TRUE)
#' 
#' @keywords package
#'
NULL